.. _api-core-controllers:

===========
Controllers
===========

Return to :ref:`api-core`.

.. automodule:: projector.core.controllers

.. view:: View

View
====

.. autoclass:: projector.core.controllers.View
   :members: response, __before__, __after__, __call__

